@@ -62,53 +62,89 @@ def get_app_cache_info():
 
 def get_repo_url_from_env():
     """
-    Read the repository URL from .env file
-    
+    Resolve repo URL/branch from (in order):
+      1) Process environment (gitURL, gitBranch)
+      2) Env files searched upward from CWD: .env or airoboEnv
+      3) If gitURL contains '/tree/<branch>', split into repo + branch
+
     Returns:
         tuple: (repo_url, branch) or (None, None) if not found
     """
     try:
-        # Look for .env file in current directory and parent directories
+        # 1) Check already-set environment variables (preferred)
+        env_repo = os.environ.get('gitURL')
+        env_branch = os.environ.get('gitBranch') or 'main'
+        if env_repo:
+            repo_url = env_repo
+            branch = env_branch
+            if '/tree/' in repo_url:
+                parts = repo_url.split('/tree/')
+                repo_url = parts[0]
+                if len(parts) > 1 and parts[1]:
+                    branch = parts[1]
+            if not repo_url.endswith('.git'):
+                repo_url += '.git'
+            return repo_url, branch
+
+        # 2) Look for .env or airoboEnv file in current and parent directories
         current_dir = Path.cwd()
         env_file = None
-        
-        # Search up the directory tree for .env file
         for parent in [current_dir] + list(current_dir.parents):
-            potential_env = parent / '.env'
-            if potential_env.exists():
-                env_file = potential_env
+            for name in ('.env', 'airoboEnv'):
+                potential = parent / name
+                if potential.exists():
+                    env_file = potential
+                    break
+            if env_file:
                 break
-        
+
+        # 2b) If not found, scan system root common locations (e.g., C:\airobo)
+        if not env_file:
+            try:
+                sys_drive = os.environ.get('SystemDrive', 'C:')
+                root = Path(sys_drive + "\\")
+                candidates = [
+                    root / 'airobo' / 'airoboEnv',
+                    root / 'airobo' / 'airoboEnv.env',
+                    root / 'airoboEnv',
+                    root / 'airoboEnv.env',
+                ]
+                for p in candidates:
+                    if p.exists():
+                        env_file = p
+                        break
+            except Exception:
+                pass
+
         if not env_file:
             return None, None
-            
-        # Read .env file and extract gitURL
-        with open(env_file, 'r') as f:
+
+        with open(env_file, 'r', encoding='utf-8') as f:
             for line in f:
                 line = line.strip()
+                if not line or line.startswith('#'):
+                    continue
                 if line.startswith('gitURL='):
                     original_url = line.split('=', 1)[1].strip()
-                    
-                    # Extract branch if it contains /tree/
-                    branch = "main"  # default branch
+                    branch = 'main'
                     repo_url = original_url
-                    
                     if '/tree/' in original_url:
                         parts = original_url.split('/tree/')
                         repo_url = parts[0]
                         if len(parts) > 1:
                             branch = parts[1]
-                    
-                    # Ensure it ends with .git for proper cloning
                     if not repo_url.endswith('.git'):
                         repo_url += '.git'
-                    
                     return repo_url, branch
-                    
+
+                if line.startswith('gitBranch='):
+                    # Will be used only if gitURL appears later in the file
+                    env_branch = line.split('=', 1)[1].strip()
+
         return None, None
-        
+
     except Exception as e:
-        print(f"⚠️ Error reading .env file: {e}")
+        print(f"⚠️ Error resolving repo from env: {e}")
         return None, None
 
 
@@ -140,7 +176,7 @@ def clone_or_pull_repo(repo_url, local_path, branch="main"):
         
         if local_path.exists() and (local_path / '.git').exists():
             # Repository already exists, pull latest changes
-            print(f"\t📂 PULLING...")
+            print(f"\t> PULLING...")
             return pull_latest_changes(local_path, branch)
         else:
             # Repository doesn't exist, clone it
@@ -164,7 +200,7 @@ def clone_repository(repo_url, local_path, branch="main"):
         cmd = ["git", "clone", "-b", branch, repo_url, str(local_path)]
         result = subprocess.run(cmd, capture_output=True, text=True, check=True)
         
-        print(f"\t✅ Successfully cloned repository to {local_path}")
+        print(f"\t- Successfully cloned repository to {local_path}")
         return {
             "success": True,
             "message": f"Repository cloned successfully to {local_path}",
@@ -200,7 +236,7 @@ def pull_latest_changes(local_path, branch="main"):
         # Return to original directory
         os.chdir(original_cwd)
         
-        print(f"\t\t✅ Successfully pulled latest changes!")
+        print(f"\t\t- Successfully pulled latest changes!")
         
         return {
             "success": True,
@@ -241,10 +277,10 @@ def get_app_source(repo_url, project_name=None, branch="main", base_path=None):
         # Construct local path in cache directory
         local_path = Path(base_path) / project_name
         
-        print(f"\t> Getting latest source:")
-        print(f"\t\t> Repository:\t{repo_url}")
-        print(f"\t\t>    ...Branch:\t\t~{branch}")
-        print(f"\t-----\n\t--> Cache path: {local_path}\n\t-----")
+        print(f"\t-----")
+        print(f"\t\t- Repository:\t{repo_url}")
+        print(f"\t\t-    ...Branch:\t\t~{branch}")
+        print(f"\n\t\t--> Cache path: {local_path}\n\t-----")
         print()
         
         # Clone or pull the repository
@@ -256,7 +292,7 @@ def get_app_source(repo_url, project_name=None, branch="main", base_path=None):
             result["cache_path"] = str(local_path)  # Specific path for cached content
             
             # Print success message with formatting
-            print(f"\t- - - - -\n\t✅ App source ready at: {local_path}\n\t- - - - -")
+            print(f"\t- - - - -\n\tAPP SOURCE READY AT: {local_path}\n\t- - - - -")
         
         return result
         
